@@ -43,7 +43,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.export(outputPath+os.sep+targetModel)
+        learn2.export(fname=outputPath+os.sep+targetModel+'.pkl')
         shutil.rmtree(path+'_tmp')
 
 
